<?php
class xoogu_simpleSocialSharing{
	
	//@var array $_options Holds the options / settings for the plugin
	protected $_options = array();
	
	public function __construct(){
		$this->_options=get_option('xoogu-simple-social-sharing');
		add_action('wp_enqueue_scripts', array($this, 'init'));
	}
	
	/**
	 *Adds the share links to the content
	 *@param string $content The content to add the share links to
	 *@return string The content with the share links added
	 */
	public function add_links($content){
		global $post;
		if( !isset($post) || !is_object($post) || empty($post->ID) ){
			if ( defined( 'WP_DEBUG_LOG' ) && WP_DEBUG_LOG ) {
				try{
					$e = new Exception();
					error_log(sprintf(__('Xoogu Simple Social Sharing: add_links called when $post empty. Stacktrace: %s', 'xoogu-simple-social-sharing'), var_export($e->getTraceAsString(), true)));
				}
				catch(Exception $e){}
			}
			return $content;
		}
		$links = $this->_options['links'];
		if(empty($links)){
			return $content;
		}
		$link = urlencode(get_permalink());
		$title=urlencode(html_entity_decode($post->post_title));
		$summary=get_post_meta( $post->ID, 'description', true);
		if(empty($summary)){
			$summary=$post->post_excerpt ? $post->post_excerpt : wp_trim_words($content,55);
		}
		$summary=urlencode($summary);
		//only pinterest and vkontakte allow specifying image in share url
		if ($links['pinterest'] || $links['vkontakte']) {
			if (has_post_thumbnail()) {
				$image_info=wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' );
				$image=$image_info[0];
			}
			else{
				$image=get_post_meta($post->ID, 'featured', true);
			}
			if ($image) {
				$image = urlencode($image);
			}
		}
		$socialLinks='';
		if($links['facebook']){
			$shareon = sprintf(__('Share on %s', 'xoogu-simple-social-sharing'), __('Facebook', 'xoogu-simple-social-sharing'));
			$socialLinks.=' <a rel="nofollow" href="https://www.facebook.com/sharer/sharer.php?u='.$link.'&amp;t='.$title.'" title="'.$shareon.'" class="xsss-fb">'.$shareon.'</a>';
		}
		if($links['twitter']){
			$shareon = sprintf(__('Share on %s', 'xoogu-simple-social-sharing'), __('Twitter', 'xoogu-simple-social-sharing'));
			$socialLinks.=' <a rel="nofollow" href="https://twitter.com/intent/tweet?url='.$link.'&amp;text='.$title.'" title="'.$shareon.'" class="xsss-t">'.$shareon.'</a>';
		}
		if($links['vkontakte']){
			$shareon = sprintf(__('Share on %s', 'xoogu-simple-social-sharing'), __('VKontakte', 'xoogu-simple-social-sharing'));
			$socialLinks.=' <a rel="nofollow" href="http://vk.com/share.php?url='.$link.'&amp;title='.$title.'&amp;description='.$summary;
			if ($image) {
				$socialLinks.='&amp;image='.$image;
			}
			$socialLinks.='" title="'.$shareon.'" class="xsss-vk">'.$shareon.'</a>';
		}
		if($links['gplus']){
			$shareon = sprintf(__('Share on %s', 'xoogu-simple-social-sharing'), __('Google+', 'xoogu-simple-social-sharing'));
			$socialLinks.=' <a rel="nofollow" href="https://plus.google.com/share?url='.$link.'" title="'.$shareon.'" class="xsss-g">'.$shareon.'</a>';
		}
		if($links['linkedin']){
			$shareon = sprintf(__('Share on %s', 'xoogu-simple-social-sharing'), __('LinkedIn™', 'xoogu-simple-social-sharing'));
			//max len of summary is 256 chars but linkedIn will shorten it if too long, so no need to shorten it ourselves
			$socialLinks.=' <a rel="nofollow" href="https://www.linkedin.com/shareArticle?url='.$link.'&amp;mini=true&amp;source='.urlencode(get_bloginfo('name')).'&amp;title='.$title.'&amp;summary='.$summary.'" title="'.$shareon.'" class="xsss-l">'.$shareon.'</a>';
		}
		if($links['pinterest']){
			$shareon = sprintf(__('Share on %s', 'xoogu-simple-social-sharing'), __('Pinterest', 'xoogu-simple-social-sharing'));
			$socialLinks.=' <a rel="nofollow" href="https://pinterest.com/pin/create/button/?url='.$link;
			if($image){
				$socialLinks.='&amp;media='.$image;
			}
			$socialLinks.='&amp;description='.$summary.'" class="xsss-p" title="'.$shareon.'" >'.$shareon.'</a>';
		}
		if($links['reddit']){
			$shareon = sprintf(__('Share on %s', 'xoogu-simple-social-sharing'), __('Reddit', 'xoogu-simple-social-sharing'));
			$socialLinks.=' <a rel="nofollow" href="https://reddit.com/submit?phase=2&amp;url='.$link.'&amp;title='.$title.'" title="'.$shareon.'" class="xsss-r">'.$shareon.'</a>';
		}
		if($links['delicious']){
			$shareon = sprintf(__('Bookmark on %s', 'xoogu-simple-social-sharing'), __('Delicious', 'xoogu-simple-social-sharing'));
			$socialLinks.=' <a rel="nofollow" href="https://delicious.com/post?url='.$link.'&amp;title='.$title.'" title="'.$shareon.'" class="xsss-d">'.$shareon.'</a>';
		}
		if($this->_options['pos-before']){
			$content='<div id="xsss-buttons-before"><h4 class="xsss-title" >'.$this->_options['title'].'</h4>'.$socialLinks.'</div>'.$content;
		}
		if($this->_options['pos-after']){
			$content.='<div id="xsss-buttons-after"><h4 class="xsss-title" >'.$this->_options['title'].'</h4>'.$socialLinks.'</div>';
		}
		return $content;
	}
	
	/**
	 *Checks if we should add the links for this page
	 *Loads the CSS and JS
	 */
	public function init()
	{
		//single pages, attachments and posts
		if ($this->_options['single']== 'singular' && !is_singular()) {
			return;
		}
		//single posts only
		if ($this->_options['single']== 'single' && !is_single()) {
			return;
		}
		//manual location in theme
		if (!empty($this->_options['manual_location'])) {
			add_filter('xsss_buttons', array($this, 'add_links'));
		}
		//above or below post content
		if ($this->_options['pos-before'] || $this->_options['pos-after']) {
			add_filter('the_content', array($this, 'add_links'));
		}
		$this->loadjscss();
	}
	
	/**
	 *Enqueues the CSS and JS if they are switched on in the options
	 *This function is separate to init (and called from init) so that
	 *it can be called from the admin for the preview
	 */
	public function loadjscss(){
		//css
		$upload_dir = wp_upload_dir( date('Y') );
		wp_enqueue_style( 'xoogu-simple-social-sharing', $upload_dir['baseurl'].'/xoogu-simple-social-sharing.css', null, $this->_options['opts_updated'] );
		
		//js
		if($this->_options['js']){
			if($this->_options['js']==='jquery'){
				wp_enqueue_script( 'xoogu-simple-social-sharing-jquery', plugins_url( 'xoogu-simple-social-sharing-jquery.js' , __FILE__ ), array('jquery'), 1, true );
			}else{
				wp_enqueue_script( 'xoogu-simple-social-sharing', plugins_url( 'xoogu-simple-social-sharing.js' , __FILE__ ), null, 2, true );
			}
		}
	}
}
